ProSHADE: ProSHADE_internal_precomputedVals Namespace Reference

| ProSHADE 0.7.5.1 (JAN 2021) Protein Shape Detection

ProSHADE_internal_precomputedVals Namespace Reference

This namespace contains the pre-computed values for the ProSHADE run. More...

## Detailed Description

This namespace contains the pre-computed values for the ProSHADE run.

The ProSHADE_internal_precomputedVals namespace contains the pre-computed numbers so that the slow functions required to obtain these would not have to be run every time ProSHADE is being used. This approach has its limits, but in some cases these do outweighht the benefits of computing everything afresh.